@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_FD.hpp 1808 2016-04-28 22:17:03Z stephane $
+ * $Id: sg_FD.hpp 1855 2016-05-24 00:22:22Z stephane $
  */
 
 #pragma once
@@ -30,6 +30,9 @@ namespace SG
 			/// Constructor.  Requires the name of the file to be opened and the mode (O_RDONLY, O_WRONLY, O_RDWR).
 			FD(const std::string &filename, const int mode);
 
+			/// Constructor.  Can be explicitly told to throw or not throw if the filename doesn't exist or cannot be opened.
+			FD(const bool throw_on_error, const std::string &filename, const int mode);
+
 			/// Destructor.
 			~FD(void);
 
