@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: seeedgrove.cpp 1867 2016-05-28 08:09:05Z stephane $
+ * $Id: seeedgrove.cpp 1904 2016-06-15 04:20:07Z stephane $
  */
 
 #include "sg++.hpp"
@@ -513,6 +513,23 @@ void button( const VStr &args )
 }
 
 
+void variable_led( const VStr &args )
+{
+	SG::VariableColorLED led;
+
+	std::cout << led.get_description() << std::endl;
+
+	std::cout << "Blinking LED, on and off for 500 milliseconds." << std::endl;
+	while ( exit_signal_detected == 0 )
+	{
+		led.turn_on( std::chrono::milliseconds(500) );
+	}
+	led.turn_off();
+
+	return;
+}
+
+
 void show_help( void )
 {
 	std::cout	<< "Command line usage:"								<< std::endl
@@ -531,6 +548,7 @@ void show_help( void )
 				<< "  oled112 [on|off|normal|invert|all_on|all_off|contrast #|lock|unlock|scroll_start|scroll_stop|left #|right #]" << std::endl
 				<< "  ledbar [on|off]"									<< std::endl
 				<< "  button"											<< std::endl
+				<< "  variable_led"										<< std::endl
 				;
 
 	return;
@@ -580,6 +598,7 @@ int seeedgrove_example_application( int argc, char **argv )
 	else if (cmd == "oled112"			)	oled112				(args);
 	else if (cmd == "ledbar"			)	ledbar				(args);
 	else if (cmd == "button"			)	button				(args);
+	else if (cmd == "variable_led"		)	variable_led		(args);
 	else if (cmd == "help"				)	show_help();
 	else if (cmd == "--help"			)	show_help();
 	else if (cmd == ""					)	show_help();
